@@ -19,9 +19,9 @@ class GOESLightCurve(LightCurve):
 
     Examples
     --------
-    import sunpy
-    goes = sunpy.lightcurve.GOESLightCurve.create()
-    goes = sunpy.lightcurve.GOESLightCurve.create('2012/06/01', '2012/06/05')
+    from sunpy import lightcurve as lc
+    goes = lc.GOESLightCurve.create()
+    goes = lc.GOESLightCurve.create('2012/06/01', '2012/06/05')
     goes.peek()
 
     References
@@ -123,6 +123,4 @@ class GOESLightCurve(LightCurve):
     def _parse_csv(filepath):
         """Parses an GOES CSV"""
         with open(filepath, 'rb') as fp:
-            # @todo: check for:
-            # "No-Data-Found for the time period requested..." error
             return "", read_csv(fp, sep=",", index_col=0, parse_dates=True)
